abacusai.prediction_feature_group — AbacusAI documentation

# `abacusai.prediction_feature_group`

## Module Contents

### Classes

`PredictionFeatureGroup` | Batch Input Feature Group

class abacusai.prediction_feature_group.PredictionFeatureGroup(client, featureGroupId=None, featureGroupVersion=None, datasetType=None, default=None, required=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Batch Input Feature Group

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - featureGroupId (str) – The unique identifier of the dataset

    - featureGroupVersion (str) –

    - datasetType (str) – dataset type

    - default (bool) – If true, this dataset is the default feature group in the model

    - required (bool) – If true…

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict